@@ -8,7 +8,11 @@ def format_power(var, n, zeroth_power=""):
         #     var = f"({var})"
         return f"{var}^{{{n}}}"
 
-def format_monomial(**exponents):
+def format_monomial(*exponents):
+    """ Format a monomial. Automatically drops variables raise to the power zero, 
+        omits exponent for variables raised to the first power. The empty monomial
+        is represented as "1".
+    """
     result = " ".join(format_power(var, e) for [var,e] in exponents if e)
     if result.strip() == "":
         result = "1"
